/// <reference path="jQuery.intellisense.js" />
/// <reference path="jquery-1.2.6.js" />
/// <reference path="jcore.js" />

singleUploadHandler = function(thumbnails, progress, options, images, errors) {

	this.thumbnails = thumbnails;
  this.progress = progress;
	
  this.options = $.extend({}, singleUploadHandler.defaults, options);
  this.images = $.extend({}, singleUploadHandler.images, images);
  this.errors = $.extend({}, singleUploadHandler.errors, errors);
  this.uploader = null;
  
  this.init();
};
singleUploadHandler.defaults = {    
    thumbnailClass : 'thumbnail',
    onStart : null,
    onComplete : null,
    filesCount : 0,
    collectionKey: '',
    fileCollectionServiceUrl : '',
    blockUI: true,
    blockUIOptions: { 
      message: '',
      overlayCSS:  { 
        backgroundColor: '#000',
        opacity: '0.0',
	    cursor: 'wait'
      }
    }    
};

singleUploadHandler.images = {
  basePath: '',
	error: 'error.png',
	toobig: 'toobig.png',
	uploadlimit: 'uploadlimit.png',
	zerobyte: 'zerobyte.png',
	invalid_file_type: 'error.png',
	progressBoxImage : 'progressbar.gif',
	progressBarImage : 'progressbg_yellow.gif'
}

singleUploadHandler.errors = {   
	displayErrors: true,
	errorCallback : function (message) {alert(message);},
	queueLimitExceeded: 'You have attempted to upload too many files.',
	internalServerError: 'Some error occured while saving the uploaded file.',
	invalidFileType: 'You have attempted to upload file of incorrect format.',
	tooBigFile: 'You have attempted to upload too big file.',
	zeroBytes: 'You have attempted to upload empty file.'
}

singleUploadHandler.prototype = {

    init : function() {
      images = this.images;
      $(this.progress).hide();
      $(this.progress).progressBar(0, {
          speed: 0,
          boxImage: images.basePath + images.progressBoxImage,
          barImage: images.basePath + images.progressBarImage
      });	                
    },

    setUploader: function(uploader) {
      this.uploader = uploader;
    },       

    debug: function(exc) {
        this.uploader.debug(exc);
    },

    displayError: function(message) {
        if (this.errors.displayErrors && typeof this.errors.errorCallback == 'function') {
            this.errors.errorCallback.call(this, message);
        }
    },
    
    resetProgressBar : function() {   
      $(this.progress).progressBar(0, {speed:0});
    },

    disableUploadButton : function() {
      this.uploader.setButtonDisabled(true);
      this.uploader.setButtonCursor(SWFUpload.CURSOR.ARROW);
      this.uploader.setButtonTextStyle(this.uploader.customSettings["disabled_styles"]);
    },
    
    enableUploadButton : function() {
      this.uploader.setButtonDisabled(false);
      this.uploader.setButtonCursor(SWFUpload.CURSOR.HAND);
      this.uploader.setButtonTextStyle(this.uploader.customSettings["enabled_styles"]);
    },
    
    checkUploadButtonAccessibility : function() {
      if (this.options.filesCount < this.uploader.settings.file_upload_limit) {
        this.enableUploadButton();
      }
      else {
        this.disableUploadButton();
      }
    },
    
    fileDeleted : function(fileID) {
      this.uploader.setFileUploadLimit(this.uploader.settings.file_upload_limit + 1);
      this.checkUploadButtonAccessibility();
    },

    addThumbnail: function(file, descriptor) {
      if (typeof file != 'undefined' && file.Thumbnail)
      {
        preview = $.create('div', {className: 'file-preview'}, [
          $.create('div', {className: 'wrapper'}, [
            $.create('div', {className: 'back'}, [
              $.create('a', {title: file.Title, href: file.Url}, [
              newImg = $.create('img', { alt: 'thunmbnail', className: this.options.thumbnailClass})]),
              $.create('div', {className: 'title'}, [
                $.create('acronym', {title: file.Title}, [String.shrink(file.FormatedTitle, 20)])
              ])
            ]),
          ]),
        ]);
        $(this.thumbnails).show();
        $(this.thumbnails).append(preview);
        newImg.bind('load', function() {
            $(this).fadeIn();
            $(this).pngFix();
        });
        newImg.attr({ src: file.Thumbnail.Url });
        if (typeof descriptor != 'undefined' && file.UniqueID)
        {
          $.create('div', {className: 'actions'}, [
            $.create('div', { className: 'delete', onmouseover: 'Tip(\'Delete file\')', onmouseout: 'UnTip()'}),
          ]).appendTo(preview);
          preview.fileBlock({
            fileCollectionServiceUrl : this.options.fileCollectionServiceUrl,
            collectionKey : this.options.collectionKey,
            fileID : descriptor.id,
            uniqueFileID : file.UniqueID,
            title : file.Title,
            uploadHandler: this
          });
        }
      }
    },

    fileQueueError: function(file, errorCode, message) {
        try {
            if (errorCode === SWFUpload.QUEUE_ERROR.QUEUE_LIMIT_EXCEEDED) {
                this.displayError(this.errors.queueLimitExceeded);
                return;
            }

            imageName = this.images.error;

            switch (errorCode) {
                case SWFUpload.QUEUE_ERROR.ZERO_BYTE_FILE:
                    imageName = this.images.zerobyte;
                    message = this.errors.zeroBytes;
                    break;
                case SWFUpload.QUEUE_ERROR.FILE_EXCEEDS_SIZE_LIMIT:
                    imageName = this.images.toobig;
                    message = this.errors.tooBigFile;
                    break;
                case SWFUpload.QUEUE_ERROR.INVALID_FILETYPE:
                    imageName = this.images.invalid_file_type;
                    message = this.errors.invalidFileType;
                    break;                
                default:
                    message = this.errors.internalServerError;
                    break;
            }

            this.addThumbnail({Title: message, FormatedTitle: message, Thumbnail : {Url : this.images.basePath + imageName}});

        } catch (exc) {
            this.debug(exc);
        }
    },


    fileDialogComplete: function(numFilesSelected, numFilesQueued) {
        try {
            if (numFilesQueued > 0) {
                this.disableUploadButton();
                this.resetProgressBar();
                $(this.progress).fadeIn();
                if (this.options.onStart && typeof this.options.onStart) {
                    this.options.onStart.call(this);
                }
          
                if (this.options.blockUI && $.blockUI) {
			            $.blockUI(this.options.blockUIOptions);
                }
                
                this.uploader.startUpload();
            }
            else {
            }
        } catch (ex) {
            this.debug(ex);
        }
    },

    uploadProgress: function(file, bytesLoaded) {
        try {
            percent = Math.ceil((bytesLoaded / file.size) * 100);
            $(this.progress).progressBar(percent, {speed:15});
            
            //Show message "Retrieving" if percent == 100 then "Generating thumbnail			
        } catch (ex) {
            this.debug(ex);
        }
    },

    uploadSuccess: function(file, serverData) {
        try {
            this.addThumbnail(eval("(" + serverData + ")"), file);
            this.options.filesCount++;
            this.resetProgressBar();
            //Show message "File uploaded"            
        } catch (ex) {
            this.debug(ex);
        }
    },

    uploadComplete: function(file) {
        try {
            /*  I want the next upload to continue automatically so I'll call startUpload here */
            if (this.uploader.getStats().files_queued > 0) {
                this.uploader.startUpload();
            } else {
                $(this.progress).hide();
                
                if (this.options.blockUI && $.blockUI) {
                  $.unblockUI();
                }                   
                
                if (this.options.onComplete && typeof this.options.onComplete) {
                    this.options.onComplete.call(this);
                }
                
                if (this.options.filesCount < this.uploader.settings.file_upload_limit) {
                  this.enableUploadButton();
                }
                //Show message "All files uploaded"
            }
        } catch (ex) {
            this.debug(ex);
        }
    },

    uploadError: function(file, errorCode, message) {
        imageName = this.images.error;
        this.resetProgressBar();        
        try {
            switch (errorCode) {
                case SWFUpload.UPLOAD_ERROR.FILE_CANCELLED:
                    try {
                        //Show message canceled.
                    }
                    catch (ex1) {
                        this.debug(ex1);
                    }
                    break;
                case SWFUpload.UPLOAD_ERROR.UPLOAD_STOPPED:
                    try {
                        //Show message stoped.
                    }
                    catch (ex2) {
                        this.debug(ex2);
                    }
                    break;
                case SWFUpload.UPLOAD_ERROR.UPLOAD_LIMIT_EXCEEDED:
                    imageName = this.images.uploadlimit;
                    break;
                default:
                    this.displayError(message);
                    break;
            }

            this.addThumbnail({Title: this.errors.internalServerError, FormatedTitle: this.errors.internalServerError, Thumbnail : {Url : this.images.basePath + imageName}});

        } catch (ex3) {
            this.debug(ex3);
        }

    }
};

(function($) {

  $.fn.fileBlock = function(options) {
  
    fileBlock = function(root, options) {
      this.root = root;
      this.options = options;
      this.init();
    };
    
    fileBlock.prototype = {
    
      init : function() {
        if (this.options.enableDelete) {
          if (this.options.deleteDirectly) {
            $('.delete', this.root).bind('click', Function.createDelegate(this, this.deleteFile));
          }
          else {
            $('.delete', this.root).bind('click', Function.createDelegate(this, this.markFileAsDeleted));
          }
        }
        else {
          this.setActionDisabled('.delete');
        }        
        
        if (this.options.enableSetMain) {
          $('.set-main', this.root).bind('click', Function.createDelegate(this, this.setMain));
        }
        else {
          this.setActionDisabled('.set-main');
        } 
              
        if (this.options.enableEdit && this.options.editUrl) {
          $('.edit', this.root).wrap(String.format('<a href="{0}"></a>', this.options.editUrl));
        }
        else {
          this.setActionDisabled('.edit');
        }
        if (!this.options.enableDelete && !this.options.enableSetMail && !(this.options.enableEdit && this.options.editUrl)){
          $(this.root).addClass('no-actions');          
        }
      },
      
      deleteFile : function() {
        if (!this.options.showDeleteConfirmation || confirm(String.format('Are you sure want to delete \'{0}\'?', this.options.title))) {
          params = {
            request: this.options.deleteRequest,
            collectionKey: this.options.collectionKey,
            uniqueFileID: this.options.uniqueFileID
          };
          

          $.getMSJSON(this.options.fileCollectionServiceUrl, params, 
                      Function.createDelegate(this, this.deleteFileHandler),
                      Function.createDelegate(this, this.errorRequestHandler));          
        }
      },
      
      deleteFileHandler : function(data, result) {
        if (typeof data != undefined) {
          if (data.IsSuccess) {
            if (typeof UnTip == 'function') {
              UnTip();
            }
            $(this.root).remove();
            if (this.options.uploadHandler) {
              this.options.uploadHandler.fileDeleted(this.options.fileID);
            }
          }
        }
      },
      
      markFileAsDeleted : function() {
        params = {
          request: this.options.MarkAsDeletedRequest,
          collectionKey: this.options.collectionKey,
          uniqueFileID: this.options.uniqueFileID
        };
        

        $.getMSJSON(this.options.fileCollectionServiceUrl, params, 
                    Function.createDelegate(this, this.markFileAsDeletedHandler),
                    Function.createDelegate(this, this.errorRequestHandler));
      },
            
      markFileAsDeletedHandler : function() {
        if (typeof data != undefined) {
          //TODO: Hide file block and show link "Restore"
        }      
      },
               
      setMain : function() {
        params = {
          request: this.options.SetMainRequest,
          collectionKey: this.options.collectionKey,
          uniqueFileID: this.options.uniqueFileID
        };
        

        $.getMSJSON(this.options.fileCollectionServiceUrl, params, 
                    Function.createDelegate(this, this.setMainHandler),
                    Function.createDelegate(this, this.errorRequestHandler));      
      },         
            
      setMainHandler : function() {
        if (typeof data != undefined) {
          $('.file-preview .main').removeClass('main');
          $('.wrapper', this.root).addClass('main');
        }
      },
      
      setActionDisabled : function(action) {
        $(action, this.root).addClass(action + '-disabled');
      },
            
      setActionEnabled : function(action) {
        $(action + '-disabled', this.root).removeClass(action);
      },
                  
	    errorRequestHandler : function(response, result) {
	      $.log('WARN', response.responseText);
	    }
    };
    
    var options = $.extend({}, $.fn.fileBlock.defaults, options);
    
    $(this).each(function() {
      new fileBlock(this, options);
    });    
  };
  
  $.fn.fileBlock.defaults = {
    enableSetMain: false,
    enableDelete: true,
    enableEdit: false,
    deleteDirectly: true,
    showDeleteConfirmation: false,
    editUrl: null,
    collectionKey: '',
    uniqueFileID: '',
    fileID: '',
    title: '',
    fileCollectionServiceUrl : '',
    deleteRequest: 'Delete',
    MarkAsDeletedRequest: 'MarkAsDeleted',
    RestoreRequest: 'Restore',
    SetMainRequest: 'SetMain',
    uploadHandler: null
	};

})(jQuery);